@@ -37,14 +37,14 @@ def to_db_decimal(
 def to_db_datetime(
     self: DatetimeField, value: Optional[datetime.datetime], instance: Union[Type[Model], Model]
 ) -> Optional[str]:
-    if hasattr(instance, "_saved_in_db"):
-        # Only do this if it is a Model instance, not class. Test for guaranteed instance var
-        if self.auto_now or (
-            self.auto_now_add and getattr(instance, self.model_field_name, None) is None
-        ):
-            value = datetime.datetime.utcnow()
-            setattr(instance, self.model_field_name, value)
-            return value.isoformat(" ")
+    # Only do this if it is a Model instance, not class. Test for guaranteed instance var
+    if hasattr(instance, "_saved_in_db") and (
+        self.auto_now
+        or (self.auto_now_add and getattr(instance, self.model_field_name, None) is None)
+    ):
+        value = datetime.datetime.utcnow()
+        setattr(instance, self.model_field_name, value)
+        return value.isoformat(" ")
     if isinstance(value, datetime.datetime):
         return value.isoformat(" ")
     return None
